@@ -1,6 +1,6 @@
 /*
 	Relay -- a tool to record and play Quake2 demos
-	Copyright (C) 1999 Conor Davis
+	Copyright (C) 2000 Conor Davis
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -17,12 +17,14 @@
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 	Conor Davis
-	cedavis@epid.org
+	cedavis@planetquake.com
 */
 
 #ifndef	__MSG_H
 #define	__MSG_H
 
+#include "q2defines.h"
+
 typedef struct msg_s
 {
 	int		id;
